@@ -6,6 +6,8 @@ CONTACT = "Michael Droettboom"
 EMAIL = "mdroe@stsci.edu"
 
 from distutils.core import setup, Extension
+from distutils.dist import Distribution
+from distutils.errors import DistutilsError
 import glob
 from os.path import join
 import os.path
@@ -78,7 +80,7 @@ except AttributeError:
 
 ######################################################################
 # WCSLIB
-WCSVERSION = "4.8.2"
+WCSVERSION = "4.10"
 WCSLIB = "wcslib" # Path to wcslib
 WCSLIB_PATCHED = "wcslib"
 WCSLIBC = join(WCSLIB_PATCHED, "C") # Path to wcslib source files
@@ -140,6 +142,33 @@ h_file.write("""
 
 /* 64-bit integer data type. */
 #define WCSLIB_INT64 %s
+
+/* Windows needs some other defines */
+/* I think the only one we need is _WIN32, but the others don't hurt - Mark S. 2012-02-14 */
+#if defined(_WIN32) || defined(_MSC_VER) || defined(__MINGW32__) || defined (__MINGW64__)
+
+/* */
+#ifndef YY_NO_UNISTD_H
+#define YY_NO_UNISTD_H
+#endif
+
+#ifndef _CRT_SECURE_NO_WARNINGS
+#define _CRT_SECURE_NO_WARNINGS
+#endif
+
+#ifndef _NO_OLDNAMES    /* for mingw32 */
+#define _NO_OLDNAMES
+#endif
+
+#ifndef NO_OLDNAMES     /* for mingw64 */
+#define NO_OLDNAMES
+#endif
+
+#ifndef __STDC__        /* for MS Visual C */
+#define __STDC__ 1
+#endif
+
+#endif
 """ % (WCSVERSION, determine_64_bit_int()))
 write_if_different(join(srcroot, 'src', 'wcsconfig.h'), h_file.getvalue())
 
@@ -233,6 +262,100 @@ PYWCS_SOURCES = [join('src', x) for x in PYWCS_SOURCES]
 
 ######################################################################
 # DISTUTILS SETUP
+
+def get_distutils_option(option, commands):
+    """ Returns the value of the given distutils option.
+
+    Parameters
+    ----------
+    option : str
+        The name of the option
+
+    commands : list of str
+        The list of commands on which this option is available
+
+    Returns
+    -------
+    val : str or None
+        the value of the given distutils option. If the option is not set,
+        returns None.
+    """
+    # Pre-parse the Distutils command-line options and config files to
+    # if the option is set.
+    dist = Distribution()
+    try:
+        dist.parse_config_files()
+        dist.parse_command_line()
+    except DistutilsError:
+        # Let distutils handle this itself
+        return None
+    except AttributeError:
+        # This seems to get thrown for ./setup.py --help
+        return None
+
+    for cmd in commands:
+        if cmd in dist.commands:
+            break
+    else:
+        return None
+
+    for cmd in commands:
+        cmd_opts = dist.get_option_dict(cmd)
+        if option in cmd_opts:
+            return cmd_opts[option][1]
+    else:
+        return None
+
+
+def adjust_compiler():
+    """
+    This function detects broken compilers and switches to another.  If
+    the environment variable CC is explicitly set, or a compiler is
+    specified on the commandline, no override is performed -- the purpose
+    here is to only override a default compiler.
+
+    The specific compilers with problems are:
+
+        * The default compiler in XCode-4.2, llvm-gcc-4.2,
+          segfaults when compiling wcslib.
+
+    The set of broken compilers can be updated by changing the
+    compiler_mapping variable.  It is a list of 2-tuples where the
+    first in the pair is a regular expression matching the version
+    of the broken compiler, and the second is the compiler to change
+    to.
+    """
+    if 'CC' in os.environ:
+        return
+
+    if get_distutils_option(
+        'compiler', ['build', 'build_ext', 'build_clib']) is not None:
+        return
+
+    from distutils import ccompiler
+    import subprocess
+    import re
+
+    compiler_mapping = [
+        ('i686-apple-darwin[0-9]*-llvm-gcc-4.2', 'clang')
+        ]
+
+    c = ccompiler.new_compiler()
+    # The MSVC ccompiler class doesn't have a `compiler` member.
+    if not hasattr(c, 'compiler'):
+        return
+    process = subprocess.Popen(
+        c.compiler + ['--version'], stdout=subprocess.PIPE)
+    output = process.communicate()[0].strip().decode('ascii')
+    version = output.split()[0]
+    for broken, fixed in compiler_mapping:
+        if re.match(broken, version):
+            os.environ['CC'] = fixed
+            break
+
+
+adjust_compiler()
+
 libraries = []
 define_macros = [('ECHO', None),
                  ('WCSTRIG_MACRO', None),
@@ -261,6 +384,8 @@ else:
     raise ValueError("BUILD should be one of 'debug', 'profile', or 'release'")
 
 if sys.platform == 'win32':
+    # we are also writing these into wcsconfig.h, but that include
+    # file is not used by wcslib
     define_macros.extend([
         ('YY_NO_UNISTD_H', None),
         ('_CRT_SECURE_NO_WARNINGS', None),
@@ -311,8 +436,9 @@ setupargs = {
         ( 'pywcs/include', ['src/*.h']),
         ( 'pywcs/include/wcslib', [ WCSLIBC + '/*.h'] ),
         ( 'pywcs/tests/maps', ['lib/pywcs/tests/maps/*.hdr']),
+        ( 'pywcs/tests/nrao', ['lib/pywcs/tests/nrao/*.hdr']),
         ( 'pywcs/tests/spectra', ['lib/pywcs/tests/spectra/*.hdr']),
-        ( 'pywcs/tests/data', ['lib/pywcs/tests/data/*.hdr'])
+        ( 'pywcs/tests/data', ['lib/pywcs/tests/data/*.hdr', 'lib/pywcs/tests/data/*.fits'])
         ],
     'package_dir' : { 'pywcs' : 'lib/pywcs', 'pywcs.tests' : 'lib/pywcs/tests'},
 }
