@@ -38,11 +38,15 @@ DAMAGE.
 #define __UTIL_H__
 
 #ifdef __SUNPRO_C
-#define inline
+#define pywcs_inline
 #endif
 
 #ifdef _MSC_VER
-#define inline __inline
+#define pywcs_inline __inline
+#endif
+
+#ifndef pywcs_inline
+#define pywcs_inline inline
 #endif
 
 #include <wcs.h>
