@@ -54,7 +54,7 @@ DAMAGE.
  * Helper functions                                                        *
  ***************************************************************************/
 
-static inline void
+static pywcs_inline void
 note_change(PyTabprm* self) {
   self->x->flag = 0;
 }
@@ -184,7 +184,7 @@ PyTabprm_print_contents(
 
   ignored = tabprt(self->x);
 
-  printf(wcsprintf_buf());
+  printf("%s", wcsprintf_buf());
 
   Py_INCREF(Py_None);
   return Py_None;
