@@ -91,7 +91,7 @@ is_valid_alt_key(
 static int
 PyWcsprm_cset(PyWcsprm* self, const int convert);
 
-static inline void
+static pywcs_inline void
 note_change(PyWcsprm* self) {
   self->x.flag = 0;
 }
@@ -524,7 +524,7 @@ PyWcsprm_celfix(
   status = celfix(&self->x);
   wcsprm_c2python(&self->x);
 
-  if (status == -1 || status == 0) {
+  if (status <= 0) {
     #if PY3K
     return PyLong_FromLong((long)status);
     #else
@@ -579,7 +579,7 @@ PyWcsprm_cylfix(
 
   Py_XDECREF(naxis_array);
 
-  if (status == -1 || status == 0) {
+  if (status <= 0) {
     #if PY3K
     return PyLong_FromLong((long)status);
     #else
@@ -601,7 +601,7 @@ PyWcsprm_datfix(
   status = datfix(&self->x);
   wcsprm_c2python(&self->x);
 
-  if (status == -1 || status == 0) {
+  if (status <= 0) {
     #if PY3K
     return PyLong_FromLong((long)status);
     #else
@@ -638,13 +638,12 @@ PyWcsprm_fix(
     const char* name;
     const int index;
   };
-  const struct message_map_entry message_map[NWCSFIX] = {
+  const struct message_map_entry message_map[5] = {
     {"datfix", DATFIX},
     {"unitfix", UNITFIX},
     {"celfix", CELFIX},
     {"spcfix", SPCFIX},
     {"cylfix", CYLFIX},
-    {NULL}
   };
   const char* keywords[] = {"translate_units", "naxis", NULL};
 
@@ -678,7 +677,7 @@ PyWcsprm_fix(
     naxis = (int*)PyArray_DATA(naxis_array);
   }
 
-  /* TODO: Use wcsfixi */
+  memset(err, 0, sizeof(struct wcserr) * NWCSFIX);
   wcsprm_python2c(&self->x);
   status = wcsfixi(ctrl, naxis, &self->x, stat, err);
   wcsprm_c2python(&self->x);
@@ -694,12 +693,16 @@ PyWcsprm_fix(
 
   for (i = 0; i < 5; ++i) {
     msg_index = stat[message_map[i].index];
-    if (msg_index > 0 && msg_index < 11) {
-      message = err[message_map[i].index].msg;
-    } else if (msg_index == 0) {
-      message = "Success";
-    } else {
-      message = "No change";
+    message = err[message_map[i].index].msg;
+    if (message == NULL || message[0] == 0) {
+      if (msg_index == FIXERR_SUCCESS) {
+        message = "Success";
+      } else if (msg_index == FIXERR_NO_CHANGE) {
+        message = "No change";
+      } else if (msg_index == FIXERR_UNITS_ALIAS &&
+                 message_map[i].index == CYLFIX){
+        message = "No change";
+      }
     }
     #if PY3K
     subresult = PyUnicode_FromString(message);
@@ -1399,7 +1402,7 @@ PyWcsprm_spcfix(
   status = spcfix(&self->x);
   wcsprm_c2python(&self->x);
 
-  if (status == -1 || status == 0) {
+  if (status <= 0) {
     #if PY3K
     return PyLong_FromLong((long)status);
     #else
@@ -1734,7 +1737,7 @@ PyWcsprm_unitfix(
 
   status = unitfix(ctrl, &self->x);
 
-  if (status == -1 || status == 0) {
+  if (status <= 0) {
     #if PY3K
     return PyLong_FromLong((long)status);
     #else
